@@ -1,5 +1,5 @@
 /**
- * @license AngularJS v1.0.6
+ * @license AngularJS v1.1.0
  * (c) 2010-2012 Google, Inc. http://angularjs.org
  * License: MIT
  */
@@ -416,13 +416,12 @@ angular.module('ngSanitize', []).value('$sanitize', $sanitize);
 angular.module('ngSanitize').directive('ngBindHtml', ['$sanitize', function($sanitize) {
   return function(scope, element, attr) {
     element.addClass('ng-binding').data('$binding', attr.ngBindHtml);
-    scope.$watch(attr.ngBindHtml, function ngBindHtmlWatchAction(value) {
+    scope.$watch(attr.ngBindHtml, function(value) {
       value = $sanitize(value);
       element.html(value || '');
     });
   };
 }]);
-
 /**
  * @ngdoc filter
  * @name ngSanitize.filter:linky
@@ -533,5 +532,4 @@ angular.module('ngSanitize').filter('linky', function() {
   };
 });
 
-
 })(window, window.angular);
